@@ -1,11 +1,9 @@
 from tethys_utils import (
-    data_models,
     hilltop,
     altitude_io,
     misc,
     processing,
     s3,
     data_io,
-    grid,
     titan,
 )
