@@ -36,6 +36,51 @@ base_encoding = {'lon': {'dtype': 'int32', '_FillValue': -999999, 'scale_factor'
 ### Functions
 
 
+def cust_range(*args, rtol=1e-05, atol=1e-08, include=[True, True]):
+    """
+    Combines numpy.arange and numpy.isclose to mimic
+    open, half-open and closed intervals.
+    Avoids also floating point rounding errors as with
+    >>> numpy.arange(1, 1.3, 0.1)
+    array([1. , 1.1, 1.2, 1.3])
+
+    args: [start, ]stop, [step, ]
+        as in numpy.arange
+    rtol, atol: floats
+        floating point tolerance as in numpy.isclose
+    include: boolean list-like, length 2
+        if start and end point are included
+    """
+    # process arguments
+    if len(args) == 1:
+        start = 0
+        stop = args[0]
+        step = 1
+    elif len(args) == 2:
+        start, stop = args
+        step = 1
+    else:
+        assert len(args) == 3
+        start, stop, step = tuple(args)
+
+    # determine number of segments
+    n = (stop-start)/step + 1
+
+    # do rounding for n
+    if np.isclose(n, np.round(n), rtol=rtol, atol=atol):
+        n = np.round(n)
+
+    # correct for start/end is exluded
+    if not include[0]:
+        n -= 1
+        start += step
+    if not include[1]:
+        n -= 1
+        stop -= step
+
+    return np.linspace(start, stop, int(n))
+
+
 def split_grid(ds, x_size=None, y_size=None, n_intervals=None, x_name='lon', y_name='lat', mbytes_size=2000):
     """
     Function to split an n-dimensional dataset along the x and y dimensions. Optionally, add time and height dimensions if the array does not aready contain them.
@@ -75,8 +120,8 @@ def split_grid(ds, x_size=None, y_size=None, n_intervals=None, x_name='lon', y_n
 
     # Get the aranges of the dimensions
     if isinstance(x_size, int) and isinstance(y_size, int):
-        x_range = np.arange(x_min, x_max+x_diff*x_size, x_diff*x_size) - x_diff/2
-        y_range = np.arange(y_min, y_max+y_diff*y_size, y_diff*y_size) - y_diff/2
+        x_range = cust_range(x_min, x_max+x_diff, x_diff*x_size) - x_diff/2
+        y_range = cust_range(y_min, y_max+y_diff, y_diff*y_size) - y_diff/2
 
     else:
         if not isinstance(n_intervals, int):
@@ -200,9 +245,9 @@ class Processor(object):
         setattr(self, 'datasets', ds_dict)
 
         ## Checks
-        grid_bool = all([d['spatial_distribution'] == 'grid' for d in dataset_list])
+        grid_bool = all([d['result_type'] == 'grid' for d in dataset_list])
         if not grid_bool:
-            raise ValueError('All values of spatial_distribution in the datasets should be grid.')
+            raise ValueError('All values of result_type in the datasets should be grid.')
 
         grouping_len = len(np.unique([d['grouping'] for d in dataset_list]))
         if grouping_len > 1:
@@ -219,11 +264,11 @@ class Processor(object):
         return dataset_list
 
 
-    def parse_paths(self, glob_str, date_format=None, from_date=None, to_date=None):
+    def parse_paths(self, glob_obj, date_format=None, from_date=None, to_date=None):
         """
 
         """
-        paths = parse_data_paths(glob_str, date_format, from_date, to_date)
+        paths = parse_data_paths(glob_obj, date_format, from_date, to_date)
 
         self.source_data_paths = paths
 
@@ -234,25 +279,6 @@ class Processor(object):
         """
         The processor takes a str path to one or many files that xr.open_mfdataset can open (e.g. netcdf) and runs a preprocessor and postprocessor (optionally) to provide the proper dimensions and names for the dataset. A Dataset can also be passed to data_path and this will skip the preprocessing step.
         """
-        ## initial loading and processing
-        # if isinstance(data_path, str):
-        #     grid1 = xr.open_mfdataset(data_path, chunks=chunks, parallel=parallel, preprocess=preprocessor)
-
-        # elif isinstance(data_path, list):
-        #     if isinstance(data_path[0], str):
-        #         paths = []
-        #         [paths.extend(glob(p)) for p in data_path]
-        #         paths.sort()
-        #         grid1 = xr.open_mfdataset(paths, chunks=chunks, parallel=parallel, preprocess=preprocessor)
-        #         data_path = paths.copy()
-        #     else:
-        #         raise TypeError('If data_path is a list, then it must be a list of str paths.')
-
-        # elif isinstance(data_path, xr.Dataset):
-        #     grid1 = data_path
-        # else:
-        #     raise TypeError('data_path must be a str path that xr.open_mfdataset can open or an xr.Dataset.')
-
         grid1 = xr.open_mfdataset(self.source_data_paths, chunks=chunks, parallel=parallel, preprocess=preprocessor)
 
         if isinstance(postprocessor, types.FunctionType):
@@ -521,9 +547,9 @@ class Grid(Titan):
         dataset_list = self.dataset_list
 
         ## Checks
-        grid_bool = all([d['spatial_distribution'] == 'grid' for d in dataset_list])
+        grid_bool = all([d['result_type'] == 'grid' for d in dataset_list])
         if not grid_bool:
-            raise ValueError('All values of spatial_distribution in the datasets should be grid.')
+            raise ValueError('All values of result_type in the datasets should be grid.')
 
         grouping_len = len(np.unique([d['grouping'] for d in dataset_list]))
         if grouping_len > 1:
@@ -540,11 +566,11 @@ class Grid(Titan):
         return dataset_list
 
 
-    def parse_paths(self, glob_str, date_format=None, from_date=None, to_date=None):
+    def parse_paths(self, glob_obj, date_format=None, from_date=None, to_date=None):
         """
 
         """
-        paths = parse_data_paths(glob_str, date_format, from_date, to_date)
+        paths = parse_data_paths(glob_obj, date_format, from_date, to_date)
 
         self.source_data_paths = paths
 
