@@ -18,6 +18,9 @@ import orjson
 from email.message import EmailMessage
 from glob import glob
 from datetime import date, datetime
+import hashlib
+import xarray as xr
+# from blake3 import blake3
 
 ############################################
 ### Parameters
@@ -32,7 +35,7 @@ def path_date_parser(path, date_format=None):
     """
 
     """
-    name1 = os.path.splitext(os.path.split(path)[1])[0]
+    name1 = os.path.split(path)[1]
     date1 = pd.to_datetime(name1, format=date_format, exact=False, infer_datetime_format=True)
 
     return date1
@@ -42,8 +45,6 @@ def filter_data_paths(paths, date_format=None, from_date=None, to_date=None, ret
     """
 
     """
-    # if isinstance(glob_str, str):
-    #     paths = glob(glob_str)
     dates = pd.DataFrame([[p, path_date_parser(p, date_format=date_format)] for p in paths], columns=['path', 'date'])
 
     if isinstance(from_date, (str, pd.Timestamp, date, datetime)):
@@ -68,11 +69,11 @@ def parse_data_paths(glob_obj, date_format=None, from_date=None, to_date=None, r
     elif isinstance(glob_obj, str):
         paths = glob(glob_obj)
 
-    if (from_date is not None) or (to_date is not None):
-        paths = filter_data_paths(paths, date_format, from_date, to_date, return_dates)
-
     paths.sort()
 
+    if (from_date is not None) or (to_date is not None) or isinstance(date_format, str):
+        paths = filter_data_paths(paths, date_format, from_date, to_date, return_dates)
+
     return paths
 
 
@@ -110,7 +111,7 @@ def write_json_zstd(data, compress_level=1):
     bytes object
 
     """
-    json1 = orjson.dumps(data, option=orjson.OPT_SERIALIZE_NUMPY)
+    json1 = orjson.dumps(data, option=orjson.OPT_NON_STR_KEYS | orjson.OPT_OMIT_MICROSECONDS | orjson.OPT_SERIALIZE_NUMPY)
     cctx = zstd.ZstdCompressor(level=compress_level)
     c_obj = cctx.compress(json1)
 
@@ -384,14 +385,63 @@ def create_shifted_df(series, from_range, to_range, freq_code, agg_fun, ref_name
     return data
 
 
-
-
-
-
-
-
-
-
+def diagnostic_check(dgn, name):
+    """
+
+    """
+    if not name in dgn:
+        raise ValueError('{} not in diagnostic.'.format(name))
+
+    if not dgn[name]['pass']:
+        raise ValueError('{} did not pass the checks. This needs to be run again.'.format(name))
+
+
+def blake2sum(file_path, buffer_size=256*1024, digest_size=12):
+    """
+    Function to hash a file using blake2 and iterating over the file via a buffer size to ensure that the function does not use too much memory.
+
+    Parameters
+    ----------
+    file_path : str or Path object
+        The path to the file to be hashed.
+    buffer_size : int
+        The buffer size in bytes.
+    digest_size : int
+        The digest size for the blake2 algorithum.
+
+    Returns
+    -------
+    str
+        hex hash of the file.
+    """
+    h = hashlib.blake2b(digest_size=digest_size)
+    # h = blake3()
+    buffer = bytearray(buffer_size)
+    # using a memoryview so that we can slice the buffer without copying it
+    buffer_view = memoryview(buffer)
+    with open(file_path, 'rb', buffering=0) as f:
+        while True:
+            n = f.readinto(buffer_view)
+            if not n:
+                break
+            h.update(buffer_view[:n])
+    return h.hexdigest()
+    # return h.hexdigest(digest_size)
+
+
+def clear_xr_objects():
+    """
+
+    """
+    n_cleaned = 0
+    objs = list(globals())
+    for obj in objs:
+        if isinstance(globals()[obj], (xr.DataArray, xr.Dataset)):
+            globals()[obj].close()
+            del globals()[obj]
+            n_cleaned = n_cleaned + 1
+
+    return n_cleaned
 
 
 
